==> ejc-assistrmat-impl-3.0.0-20220421.070000-78-sources.jar: com/ejianc/business/assist/store/service/impl/AllotOutBpmServiceImpl.java <==
package com.ejianc.business.assist.store.service.impl;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.ejianc.business.assist.store.bean.AllotInDetailEntity;
import com.ejianc.business.assist.store.bean.AllotInEntity;
import com.ejianc.business.assist.store.bean.AllotOutEntity;
import com.ejianc.business.assist.store.consts.AllocationState;
import com.ejianc.business.assist.store.consts.InOutTypeEnum;
import com.ejianc.business.assist.store.consts.NoticeEnum;
import com.ejianc.business.assist.store.service.AllotInMessageService;
import com.ejianc.business.assist.store.service.IAllotInService;
import com.ejianc.business.assist.store.service.IAllotOutService;
import com.ejianc.business.assist.store.service.StoreManageService;
import com.ejianc.business.assist.store.vo.AllotInVO;
import com.ejianc.business.assist.store.vo.AllotOutVO;
import com.ejianc.business.assist.store.vo.StoreManageVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.cache.utils.RedisTool;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import redis.clients.jedis.Jedis;
import redis.clients.jedis.JedisPool;

import java.util.List;
import java.util.Objects;

@Service("allotOut")
public class AllotOutBpmServiceImpl implements ICommonBusinessService {


	private Logger logger = LoggerFactory.getLogger(this.getClass());
	@Autowired
	private IAllotOutService service;
	@Autowired
	private IBillTypeApi billTypeApi;
	@Autowired
	private IAllotInService allotInService;
	@Autowired
	private AllotInMessageService allotInMessageService;
	private static final String BILL_CODE = "STORE_ALLOT_IN";//此处需要根据实际修改
	@Autowired
	private IBillCodeApi billCodeApi;
	@Autowired
	private JedisPool jedisPool;
	@Autowired
	StoreManageService storeManageService;

	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO

		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {

		return CommonResponse.error("该单据不支持弃审和撤回");
	};

	/**
	 * 有审批流的撤回后回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		//加锁防止生成多个调拨入库
		Jedis jedis = jedisPool.getResource();
		boolean locked = false;
		locked = RedisTool.tryLock(jedis, String.valueOf(billId), "generateAllotIn", 1000);
		logger.info("判断单据单据锁结果------"+locked);
		try{
			if (locked){
				//更新流水
				AllotOutEntity allotOutEntity = service.selectById(billId);
				AllotOutVO allotoutvo = BeanMapper.map(allotOutEntity, AllotOutVO.class);
				if (CollectionUtils.isNotEmpty(allotOutEntity.getAllotOutDetailList())){
					StoreManageVO storeManageVO = new StoreManageVO();
					storeManageVO.setStoreId(allotOutEntity.getStoreId());
					storeManageVO.setInOutTypeEnum(InOutTypeEnum.调拨出库);
					storeManageVO.setOutEffectiveON(true);
					storeManageVO.setSourceId(allotOutEntity.getId());
					storeManageService.inOutStore(storeManageVO);
				}
				if (!Objects.isNull(allotOutEntity)){
					//提交 收料状态设置带收清空退回原因
					LambdaUpdateWrapper<AllotOutEntity> allotOutWrapper = new LambdaUpdateWrapper<>();
					allotOutWrapper.eq(AllotOutEntity::getId, billId);
					allotOutWrapper.set(AllotOutEntity::getReceiveState, Integer.parseInt(AllocationState.TO_RECEIVING.getCode()));
					allotOutWrapper.set(AllotOutEntity::getReturnReason,null);
					allotOutWrapper.set(AllotOutEntity::getReceiverPersonId,null);
					allotOutWrapper.set(AllotOutEntity::getReceiverPerson,null);
					service.update(allotOutWrapper);

					//生成调拨入库
					AllotInEntity allotInEntity = new AllotInEntity();
					//出库信息
					allotInEntity.setOutAllocaScope(allotOutEntity.getOutAllocaScope());
					allotInEntity.setOutProjectId(allotOutEntity.getProjectId());
					allotInEntity.setOutProjectName(allotOutEntity.getProjectName());
					allotInEntity.setOutOrgId(allotOutEntity.getOrgId());
					allotInEntity.setOutOrgName(allotOutEntity.getOrgName());
					//入库信息
					allotInEntity.setOutTaxMny(allotOutEntity.getOutTaxMny());
					allotInEntity.setInAllocaScope(allotOutEntity.getInAllocaScope());
					allotInEntity.setStoreId(allotOutEntity.getInStoreId());
					allotInEntity.setStoreName(allotOutEntity.getInStoreName());
					allotInEntity.setProjectId(allotOutEntity.getInProjectId());
					allotInEntity.setProjectName(allotOutEntity.getInProjectName());
					allotInEntity.setParentOrgId(allotOutEntity.getInParentOrgId());
					allotInEntity.setParentOrgName(allotOutEntity.getInParentOrgName());
					allotInEntity.setParentOrgCode(allotOutEntity.getInParentOrgCode());
					allotInEntity.setOrgId(allotOutEntity.getInOrgId());
					allotInEntity.setOrgName(allotOutEntity.getInOrgName());
					allotInEntity.setAllotOutId(allotOutEntity.getId());
					allotInEntity.setOutMny(allotOutEntity.getOutMny());
					allotInEntity.setOutDate(allotOutEntity.getOutDate());
					allotInEntity.setEmployeeId(allotOutEntity.getEmployeeId());
					allotInEntity.setEmployeeName(allotOutEntity.getEmployeeName());
					allotInEntity.setDepartmentId(allotOutEntity.getDepartmentId());
					allotInEntity.setDepartmentName(allotOutEntity.getDepartmentName());
					allotInEntity.setOutStoreId(allotOutEntity.getStoreId());
					allotInEntity.setOutStoreName(allotOutEntity.getStoreName());
					allotInEntity.setNotifyReceiverId(allotOutEntity.getReceiverId());
					allotInEntity.setReceiverName(allotOutEntity.getReceiverName());
					allotInEntity.setAllocatType(allotOutEntity.getAllocatType());
					allotInEntity.setMemo(allotOutEntity.getMemo());
					allotInEntity.setMaterialNames(allotOutEntity.getMaterialNames());
					allotInEntity.setReceiveState(Integer.valueOf(AllocationState.TO_RECEIVING.getCode()));
					long id = IdWorker.getId();
					if (CollectionUtils.isNotEmpty(allotOutEntity.getAllotOutDetailList())){
						List<AllotInDetailEntity> allotInDetailEntitys = BeanMapper.mapList(allotOutEntity.getAllotOutDetailList(), AllotInDetailEntity.class);
						allotInDetailEntitys.forEach(item->{
							item.setId(null);
							item.setAllocatId(id);
						});
						allotInEntity.setAllotInDetailList(allotInDetailEntitys);
						logger.info("子表信息："+allotInDetailEntitys.toString());
					}
					AllotInVO vo = BeanMapper.map(allotInEntity, AllotInVO.class);
					BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(),vo);
					CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
					if(billCode.isSuccess()) {
						allotInEntity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
					}else{
						throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
					}
					allotInEntity.setId(id);
					boolean b = allotInService.saveOrUpdate(allotInEntity,false);
					if (b){
						AllotInEntity allot = allotInService.selectById(id);
						if ((allot!=null) && (allot.getNotifyReceiverId()!=null)){
							//通知收料人收料
							String[] notifyReceive = {String.valueOf(allot.getNotifyReceiverId())};
							allotInMessageService.sendMsg(allot,notifyReceive, NoticeEnum.ALLOTIN_ENROLL);
						}
					}
				}
			}
			else{
				return CommonResponse.error("出现并发操作,请稍后重试！");
			}
		}catch (Exception e){
			e.printStackTrace();
		} finally {
			if(locked) {
				RedisTool.releaseLock(jedis, String.valueOf(billId), "generateAllotIn");
			}
			jedis.close();
		}
		return CommonResponse.success();
	}


	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		AllotOutEntity entity = service.selectById(billId);
		if (BillStateEnum.COMMITED_STATE.getBillStateCode() == entity.getBillState()|| BillStateEnum.PASSED_STATE.getBillStateCode() == entity.getBillState()){
			return CommonResponse.error("该单据已推送给调入方，不允许撤回！");
		}
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

}

==> ejc-assistrmat-impl-3.0.0-20220422.092315-80-sources.jar: com/ejianc/business/assist/store/service/impl/AllotOutBpmServiceImpl.java <==
package com.ejianc.business.assist.store.service.impl;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.ejianc.business.assist.store.bean.AllotInDetailEntity;
import com.ejianc.business.assist.store.bean.AllotInEntity;
import com.ejianc.business.assist.store.bean.AllotOutEntity;
import com.ejianc.business.assist.store.consts.AllocationState;
import com.ejianc.business.assist.store.consts.InOutTypeEnum;
import com.ejianc.business.assist.store.consts.NoticeEnum;
import com.ejianc.business.assist.store.service.AllotInMessageService;
import com.ejianc.business.assist.store.service.IAllotInService;
import com.ejianc.business.assist.store.service.IAllotOutService;
import com.ejianc.business.assist.store.service.StoreManageService;
import com.ejianc.business.assist.store.vo.AllotInVO;
import com.ejianc.business.assist.store.vo.AllotOutVO;
import com.ejianc.business.assist.store.vo.StoreManageVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.cache.utils.RedisTool;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import redis.clients.jedis.Jedis;
import redis.clients.jedis.JedisPool;

import java.util.List;
import java.util.Objects;

@Service("allotOut")
public class AllotOutBpmServiceImpl implements ICommonBusinessService {


	private Logger logger = LoggerFactory.getLogger(this.getClass());
	@Autowired
	private IAllotOutService service;
	@Autowired
	private IBillTypeApi billTypeApi;
	@Autowired
	private IAllotInService allotInService;
	@Autowired
	private AllotInMessageService allotInMessageService;
	private static final String BILL_CODE = "STORE_ALLOT_IN";//此处需要根据实际修改
	@Autowired
	private IBillCodeApi billCodeApi;
	@Autowired
	private JedisPool jedisPool;
	@Autowired
	StoreManageService storeManageService;

	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO

		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {

		return CommonResponse.error("该单据不支持弃审和撤回");
	};

	/**
	 * 有审批流的撤回后回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		//加锁防止生成多个调拨入库
		Jedis jedis = jedisPool.getResource();
		boolean locked = false;
		locked = RedisTool.tryLock(jedis, String.valueOf(billId), "generateAllotIn", 1000);
		logger.info("判断单据单据锁结果------"+locked);
		try{
			if (locked){
				//更新流水
				AllotOutEntity allotOutEntity = service.selectById(billId);
				AllotOutVO allotoutvo = BeanMapper.map(allotOutEntity, AllotOutVO.class);
				if (CollectionUtils.isNotEmpty(allotOutEntity.getAllotOutDetailList())){
					StoreManageVO storeManageVO = new StoreManageVO();
					storeManageVO.setStoreId(allotOutEntity.getStoreId());
					storeManageVO.setInOutTypeEnum(InOutTypeEnum.调拨出库);
					storeManageVO.setOutEffectiveON(true);
					storeManageVO.setSourceId(allotOutEntity.getId());
					storeManageService.inOutStore(storeManageVO);
				}
				if (!Objects.isNull(allotOutEntity)){
					//提交 收料状态设置带收清空退回原因
					LambdaUpdateWrapper<AllotOutEntity> allotOutWrapper = new LambdaUpdateWrapper<>();
					allotOutWrapper.eq(AllotOutEntity::getId, billId);
					allotOutWrapper.set(AllotOutEntity::getReceiveState, Integer.parseInt(AllocationState.TO_RECEIVING.getCode()));
					allotOutWrapper.set(AllotOutEntity::getReturnReason,null);
					allotOutWrapper.set(AllotOutEntity::getReceiverPersonId,null);
					allotOutWrapper.set(AllotOutEntity::getReceiverPerson,null);
					service.update(allotOutWrapper);

					//生成调拨入库
					AllotInEntity allotInEntity = new AllotInEntity();
					//出库信息
					allotInEntity.setOutAllocaScope(allotOutEntity.getOutAllocaScope());
					allotInEntity.setOutProjectId(allotOutEntity.getProjectId());
					allotInEntity.setOutProjectName(allotOutEntity.getProjectName());
					allotInEntity.setOutOrgId(allotOutEntity.getOrgId());
					allotInEntity.setOutOrgName(allotOutEntity.getOrgName());
					//入库信息
					allotInEntity.setOutTaxMny(allotOutEntity.getOutTaxMny());
					allotInEntity.setInAllocaScope(allotOutEntity.getInAllocaScope());
					allotInEntity.setStoreId(allotOutEntity.getInStoreId());
					allotInEntity.setStoreName(allotOutEntity.getInStoreName());
					allotInEntity.setProjectId(allotOutEntity.getInProjectId());
					allotInEntity.setProjectName(allotOutEntity.getInProjectName());
					allotInEntity.setParentOrgId(allotOutEntity.getInParentOrgId());
					allotInEntity.setParentOrgName(allotOutEntity.getInParentOrgName());
					allotInEntity.setParentOrgCode(allotOutEntity.getInParentOrgCode());
					allotInEntity.setOrgId(allotOutEntity.getInOrgId());
					allotInEntity.setOrgName(allotOutEntity.getInOrgName());
					allotInEntity.setAllotOutId(allotOutEntity.getId());
					allotInEntity.setOutMny(allotOutEntity.getOutMny());
					allotInEntity.setOutDate(allotOutEntity.getOutDate());
					allotInEntity.setEmployeeId(allotOutEntity.getEmployeeId());
					allotInEntity.setEmployeeName(allotOutEntity.getEmployeeName());
					allotInEntity.setDepartmentId(allotOutEntity.getDepartmentId());
					allotInEntity.setDepartmentName(allotOutEntity.getDepartmentName());
					allotInEntity.setOutStoreId(allotOutEntity.getStoreId());
					allotInEntity.setOutStoreName(allotOutEntity.getStoreName());
					allotInEntity.setNotifyReceiverId(allotOutEntity.getReceiverId());
					allotInEntity.setReceiverName(allotOutEntity.getReceiverName());
					allotInEntity.setAllocatType(allotOutEntity.getAllocatType());
					allotInEntity.setMemo(allotOutEntity.getMemo());
					allotInEntity.setMaterialNames(allotOutEntity.getMaterialNames());
					allotInEntity.setReceiveState(Integer.valueOf(AllocationState.TO_RECEIVING.getCode()));
					long id = IdWorker.getId();
					if (CollectionUtils.isNotEmpty(allotOutEntity.getAllotOutDetailList())){
						List<AllotInDetailEntity> allotInDetailEntitys = BeanMapper.mapList(allotOutEntity.getAllotOutDetailList(), AllotInDetailEntity.class);
						allotInDetailEntitys.forEach(item->{
							item.setId(null);
							item.setAllocatId(id);
						});
						allotInEntity.setAllotInDetailList(allotInDetailEntitys);
						logger.info("子表信息："+allotInDetailEntitys.toString());
					}
					AllotInVO vo = BeanMapper.map(allotInEntity, AllotInVO.class);
					BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(),vo);
					CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
					if(billCode.isSuccess()) {
						allotInEntity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
					}else{
						throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
					}
					allotInEntity.setId(id);
					boolean b = allotInService.saveOrUpdate(allotInEntity,false);
					if (b){
						AllotInEntity allot = allotInService.selectById(id);
						if ((allot!=null) && (allot.getNotifyReceiverId()!=null)){
							//通知收料人收料
							String[] notifyReceive = {String.valueOf(allot.getNotifyReceiverId())};
							allotInMessageService.sendMsg(allot,notifyReceive, NoticeEnum.ALLOTIN_ENROLL);
						}
					}
				}logger.info("周转材采购调拨出库审批通过try方法");
			}
			else{
				return CommonResponse.error("出现并发操作,请稍后重试！");
			}
		}catch (Exception e){
			e.printStackTrace();
		} finally {
			if(locked) {
				RedisTool.releaseLock(jedis, String.valueOf(billId), "generateAllotIn");
			}
			jedis.close();
			logger.info("周转材采购调拨出库审批通过finally方法");
		}
		logger.info("周转材采购调拨出库审批通过------billTypeCode-{},state-{}",billTypeCode,state);
		return CommonResponse.success();
	}


	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		AllotOutEntity entity = service.selectById(billId);
		if (BillStateEnum.COMMITED_STATE.getBillStateCode() == entity.getBillState()|| BillStateEnum.PASSED_STATE.getBillStateCode() == entity.getBillState()){
			return CommonResponse.error("该单据已推送给调入方，不允许撤回！");
		}
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

}
